@@ -128,6 +128,9 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
         if constants.CUSTOM_AUDIO_STATE in self._custom_commands:
             return self._custom_commands[constants.CUSTOM_AUDIO_STATE]
 
+        # Is this an Android 11 device?
+        if self.DEVICE_ENUM == constants.DeviceEnum.ANDROIDTV and self.device_properties.get("sw_version", "") == "11":
+            return constants.CMD_AUDIO_STATE11
         return constants.CMD_AUDIO_STATE
 
     def _cmd_current_app(self):
@@ -150,6 +153,10 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
         ):
             return constants.CMD_CURRENT_APP_GOOGLE_TV
 
+        # Is this an Android 11 device?
+        if self.DEVICE_ENUM == constants.DeviceEnum.ANDROIDTV and self.device_properties.get("sw_version", "") == "11":
+            return constants.CMD_CURRENT_APP11
+
         return constants.CMD_CURRENT_APP
 
     def _cmd_current_app_media_session_state(self):
@@ -172,6 +179,10 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
         ):
             return constants.CMD_CURRENT_APP_MEDIA_SESSION_STATE_GOOGLE_TV
 
+        # Is this an Android 11 device?
+        if self.DEVICE_ENUM == constants.DeviceEnum.ANDROIDTV and self.device_properties.get("sw_version", "") == "11":
+            return constants.CMD_CURRENT_APP_MEDIA_SESSION_STATE11
+
         return constants.CMD_CURRENT_APP_MEDIA_SESSION_STATE
 
     def _cmd_hdmi_input(self):
@@ -186,6 +197,10 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
         if constants.CUSTOM_HDMI_INPUT in self._custom_commands:
             return self._custom_commands[constants.CUSTOM_HDMI_INPUT]
 
+        # Is this an Android 11 device?
+        if self.DEVICE_ENUM == constants.DeviceEnum.ANDROIDTV and self.device_properties.get("sw_version", "") == "11":
+            return constants.CMD_HDMI_INPUT11
+
         return constants.CMD_HDMI_INPUT
 
     def _cmd_launch_app(self, app):
@@ -216,6 +231,10 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
         if self.DEVICE_ENUM == constants.DeviceEnum.FIRETV:
             return constants.CMD_LAUNCH_APP_FIRETV.format(app)
 
+        # Is this an Android 11 device?
+        if self.DEVICE_ENUM == constants.DeviceEnum.ANDROIDTV and self.device_properties.get("sw_version", "") == "11":
+            return constants.CMD_LAUNCH_APP11.format(app)
+
         return constants.CMD_LAUNCH_APP.format(app)
 
     def _cmd_running_apps(self):
